@@ -64,6 +64,12 @@ mc4_mthds <- function() {
       e1 <- bquote(dat[ , osd := sd(resp[cndx %in% 1:2 & wllt == "t"], na.rm = TRUE)])
       list(e1)
       
+    },
+    bidirectional.false = function() {
+      
+      e1 <- bquote(dat[ ,bidirectional := FALSE])
+      list(e1)
+      
     },
     bmed.aeid.lowconc.twells = function() {
       
